import * as Cesium from 'cesium'
const dataLoading = {
    addWMTSLayer: function (viewer, layerUrl,layerName, epsgCode,extent) {
        let matrixIds = [];
        for(let i=0;i<20;i++){
            matrixIds.push(epsgCode+":"+i)
        }
    
        //1.新建ImageryProvider
        let wmtsImageryProvider = new Cesium.WebMapTileServiceImageryProvider({
        url: layerUrl, //服务地址，如：'http://localhost:8080/geoserver/gwc/service/wmts'
        layer: layerName, //图层名称，如：'tiger:tiger_roads'
        style: "",
        format: "image/png",
        tileMatrixSetID: epsgCode,
        tileMatrixLabels: matrixIds,
        rectangle: new Cesium.Rectangle(
            Cesium.Math.toRadians(extent[0]),
            Cesium.Math.toRadians(extent[1]),
            Cesium.Math.toRadians(extent[2]),
            Cesium.Math.toRadians(extent[3])
        ),
        // 切图策略采用地理坐标的方案，4326是没有进行投影的地理坐标系
        tilingScheme: new Cesium.GeographicTilingScheme({
            //此处很重要，很重要。。。
            numberOfLevelZeroTilesX: 2,
            numberOfLevelZeroTilesY: 1,
        }),
        });

        //2.新建imageryLayer
        let imageryLayer = new Cesium.ImageryLayer(wmtsImageryProvider, {
        // show: visible,//是否可见
        // alpha: opacity//透明度
        });

        //3.将imageryLayer加入到viewer中
        viewer.imageryLayers.add(imageryLayer);
        
    },
    addWFSLayer: async function(viewer,url){
        let tmpPrimitives = viewer.scene.primitives.add(new Cesium.PrimitiveCollection());
        let colorStr = "rgba(255,255,255,0.01)";

        fetch(url).then(res=>res.json()).then(result=>{
            console.log(result)
      
            result.features.forEach(feature=>{
                const polygon = new Cesium.PolygonGeometry({
                    polygonHierarchy : new Cesium.PolygonHierarchy(
                      Cesium.Cartesian3.fromDegreesArrayHeights(feature.geometry.coordinates[0].flat(2))
                    )
                  });
                tmpPrimitives.add(new Cesium.Primitive({
                    geometryInstances : new Cesium.GeometryInstance({
                      geometry: polygon,
                      attributes : {
                        // 通过attributes属性统一指定线段颜色
                        color : Cesium.ColorGeometryInstanceAttribute.fromColor(Cesium.Color.fromCssColorString(colorStr?colorStr:"red"))
                      },
                      id:JSON.stringify(feature.properties)
                    }),
                    appearance : new Cesium.PerInstanceColorAppearance({
                        flat: true,
                        translucent : true,
                    })
                }));
            })
        })
    }
}

export default dataLoading;